"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from livepeer_ai.types import BaseModel
from typing_extensions import TypedDict


class MediaURLTypedDict(TypedDict):
    r"""A URL from which media can be accessed."""

    url: str
    r"""The URL where the media can be accessed."""


class MediaURL(BaseModel):
    r"""A URL from which media can be accessed."""

    url: str
    r"""The URL where the media can be accessed."""
