"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from livepeer_ai.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class TextToSpeechParamsTypedDict(TypedDict):
    model_id: NotRequired[str]
    r"""Hugging Face model ID used for text to speech generation."""
    text: NotRequired[str]
    r"""Text input for speech generation."""
    description: NotRequired[str]
    r"""Description of speaker to steer text to speech generation."""


class TextToSpeechParams(BaseModel):
    model_id: Optional[str] = ""
    r"""Hugging Face model ID used for text to speech generation."""

    text: Optional[str] = ""
    r"""Text input for speech generation."""

    description: Optional[str] = (
        "A male speaker delivers a slightly expressive and animated speech with a moderate speed and pitch."
    )
    r"""Description of speaker to steer text to speech generation."""
